=======
Widgets
=======

.. autoclass:: import_export.widgets.Widget
   :members:

.. autoclass:: import_export.widgets.NumberWidget
   :members:

.. autoclass:: import_export.widgets.IntegerWidget
   :members:

.. autoclass:: import_export.widgets.DecimalWidget
   :members:

.. autoclass:: import_export.widgets.CharWidget
   :members:

.. autoclass:: import_export.widgets.BooleanWidget
   :members:

.. autoclass:: import_export.widgets.DateWidget
   :members:

.. autoclass:: import_export.widgets.TimeWidget
  :members:

.. autoclass:: import_export.widgets.DateTimeWidget
   :members:

.. autoclass:: import_export.widgets.DurationWidget
   :members:

.. autoclass:: import_export.widgets.JSONWidget
   :members:

.. autoclass:: import_export.widgets.ForeignKeyWidget
   :members:

.. autoclass:: import_export.widgets.ManyToManyWidget
   :members:
